import { PLACEHOLDER } from "./constants";
import { FunctionComponent, ReactElement, RefObject } from "react";
import { OptionProps } from "./components/Option";
import { MarkedInputProps } from "./components/MarkedInput";
import { EventBus } from "./utils/EventBus";
export declare type NodeData = {
    key: number;
    mark: Mark;
    ref?: RefObject<HTMLElement>;
};
export interface Mark {
    label: string;
    value?: string;
}
export interface AnnotatedMark extends Mark {
    annotation: string;
    label: string;
    value: string;
    index: number;
    input: string;
    childIndex: number;
}
export interface MarkProps extends Mark {
}
export interface OverlayProps {
    /**
     * Style with caret absolute position. Used for placing an overlay.
     */
    style: {
        left: number;
        top: number;
    };
    /**
     * Used for close overlay.
     */
    onClose: () => void;
    /**
     * Used for insert an annotation instead a triggered value.
     */
    onSelect: (value: Mark) => void;
    /**
     * Trigger details
     */
    trigger: Trigger;
}
declare type label = `${string}${PLACEHOLDER.LABEL}${string}`;
declare type value = `${string}${PLACEHOLDER.VALUE}${string}`;
export declare type Markup = `${label}${value}` | `${label}`;
export declare type ElementOptions<T> = ReactElement<OptionProps<T>> | ReactElement<OptionProps<T>>[];
/** Piece of marked text: fragment of text or mark definition */
export declare type Piece = string | AnnotatedMark;
export declare type KeyedPieces = Map<number, Piece>;
declare type PartialPick<T, F extends keyof T> = Omit<Required<T>, F> & Partial<Pick<T, F>>;
export declare type OptionType = PartialPick<OptionProps, "initMark" | "initOverlay"> & {
    index: number;
};
export declare type Options = OptionType[];
export declare type ConfiguredMarkedInputProps<T, T1 = OverlayProps> = Omit<MarkedInputProps<T, T1>, "Mark" | "Overlay" | "children">;
export declare type ConfiguredMarkedInput<T, T1 = OverlayProps> = FunctionComponent<ConfiguredMarkedInputProps<T, T1>>;
export declare type Store = {
    options: Options;
    bus: EventBus;
    props: ExtractedProps;
};
export declare type ExtractedProps = Omit<MarkedInputProps, 'children' | 'value'>;
export declare type EventName = `on${string}`;
export declare enum Type {
    Change = 0,
    Delete = 1,
    CheckTrigger = 2,
    ClearTrigger = 3,
    Select = 4
}
export declare type Payload = {
    key: number;
    value?: Mark;
};
export declare type Trigger = {
    /**
     * Found value via a trigger
     */
    value: string;
    /**
     * Triggered value
     */
    source: string;
    /**
     * Piece of text, in which was a trigger
     */
    span: string;
    /**
     * Html element, in which was a trigger
     */
    node: Node;
    /**
     * Start position of a trigger
     */
    index: number;
    /**
     * Trigger's option
     */
    option: OptionType;
};
export declare type KeyMapper = {
    "TextRef": RefObject<HTMLDivElement>;
    "TriggerSpanRef": RefObject<HTMLElement>;
};
export declare type Listener = (e: any) => void;
declare type EventsFrom<Type extends object> = {
    [Key in keyof Type & `on${string}`]+?: Type[Key];
};
export declare type DivEvents = EventsFrom<JSX.IntrinsicElements['div']>;
export declare type Activator = () => void;
export {};
//# sourceMappingURL=types.d.ts.map