import { Mark, NodeData } from "../types";
import { CSSProperties, RefObject } from "react";
export interface DynamicMark extends Mark {
    /**
     * Register a mark ref. Used for focusing and key operation.
     */
    reg: ReturnType<typeof useRegistration>;
    /**
     * Change mark.
     * @silent doesn't change itself label and value, only pass change event.
     */
    onChange: (props: Mark, options?: {
        silent: boolean;
    }) => void;
    /**
     * Remove itself.
     */
    onRemove: () => void;
    /**
     * Passed the readOnly prop value
     */
    readOnly?: boolean;
    /**
     * Passed style of span
     */
    style?: CSSProperties;
    /**
     * Passed class name of span
     */
    className?: string;
    /**
     * Held caret position in html element at rerender: save the position then restore this.
     *
     * Can be used on change event of editable text tags like <span>, <bold>, etc.
     */
    heldCaret: (element: HTMLElement) => void;
}
export declare const useMark: () => DynamicMark;
declare function useRegistration(node: NodeData): (elementOrRef: HTMLElement | RefObject<HTMLElement> | null) => void;
export {};
//# sourceMappingURL=useMark.d.ts.map